@@ -2,6 +2,8 @@ package main
 
 import (
 	"os"
+	"os/signal"
+	"syscall"
 
 	flags "github.com/jessevdk/go-flags"
 	log "github.com/sirupsen/logrus"
@@ -11,6 +13,12 @@ import (
 	storkutil "isc.org/stork/util"
 )
 
+// Global Agent settings.
+type AgentSettings struct {
+	PrometheusOnly bool `long:"listen-prometheus-only" description:"listen only for Prometheus requests" env:"STORK_AGENT_LISTEN_PROMETHEUS_ONLY"`
+	StorkOnly      bool `long:"listen-stork-only" description:"listen only for Stork Server requests" env:"STORK_AGENT_LISTEN_STORK_ONLY"`
+}
+
 func main() {
 	// Setup logging
 	storkutil.SetupLogging()
@@ -27,11 +35,17 @@ func main() {
 	promBind9Exporter := agent.NewPromBind9Exporter(appMonitor)
 
 	// Prepare parse for command line flags.
-	parser := flags.NewParser(&storkAgent.Settings, flags.Default)
+	var agentSettings AgentSettings
+	parser := flags.NewParser(&agentSettings, flags.Default)
 	parser.ShortDescription = "Stork Agent"
 	parser.LongDescription = "Stork Agent"
 
-	_, err := parser.AddGroup("Prometheus Kea Exporter flags", "", &promKeaExporter.Settings)
+	_, err := parser.AddGroup("Stork Server flags", "", &storkAgent.Settings)
+	if err != nil {
+		log.Fatalf("FATAL error: %+v", err)
+	}
+
+	_, err = parser.AddGroup("Prometheus Kea Exporter flags", "", &promKeaExporter.Settings)
 	if err != nil {
 		log.Fatalf("FATAL error: %+v", err)
 	}
@@ -42,20 +56,31 @@ func main() {
 	}
 
 	if _, err := parser.Parse(); err != nil {
-		code := 1
 		if fe, ok := err.(*flags.Error); ok {
 			if fe.Type == flags.ErrHelp {
-				code = 0
+				os.Exit(0)
 			}
 		}
-		os.Exit(code)
+		log.Fatalf("FATAL error: %+v", err)
 	}
 
-	promKeaExporter.Start()
-	defer promKeaExporter.Shutdown()
+	// Only start the exporters if they're enabled.
+	if !agentSettings.StorkOnly {
+		promKeaExporter.Start()
+		defer promKeaExporter.Shutdown()
 
-	promBind9Exporter.Start()
-	defer promBind9Exporter.Shutdown()
+		promBind9Exporter.Start()
+		defer promBind9Exporter.Shutdown()
+	}
 
-	storkAgent.Serve()
+	// Only start the agent service if it's enabled.
+	if !agentSettings.PrometheusOnly {
+		go storkAgent.Serve()
+		defer storkAgent.Shutdown()
+	}
+
+	// We wait for ctl-c
+	c := make(chan os.Signal, 1)
+	signal.Notify(c, os.Interrupt, syscall.SIGINT)
+	<-c
 }
