@@ -10,6 +10,16 @@ import (
 	agentapi "isc.org/stork/api"
 )
 
+// makeAccessPoint is an utility to make single element app access point slice.
+func makeAccessPoint(tp, address, key string, port int64) (ap []*agentapi.AccessPoint) {
+	return append(ap, &agentapi.AccessPoint{
+		Type:    tp,
+		Address: address,
+		Port:    port,
+		Key:     key,
+	})
+}
+
 // Setup function for the unit tests. It creates a fake agent running at
 // 127.0.0.1:8080. The returned function performs a test teardown and
 // should be invoked when the unit test finishes.
@@ -44,9 +54,8 @@ func TestGetState(t *testing.T) {
 		AgentVersion: expVer,
 		Apps: []*agentapi.App{
 			{
-				Type:        "kea",
-				CtrlAddress: "1.2.3.4",
-				CtrlPort:    1234,
+				Type:         AppTypeKea,
+				AccessPoints: makeAccessPoint(AccessPointControl, "1.2.3.4", "", 1234),
 			},
 		},
 	}
@@ -58,7 +67,7 @@ func TestGetState(t *testing.T) {
 	state, err := agents.GetState(ctx, "127.0.0.1", 8080)
 	require.NoError(t, err)
 	require.Equal(t, expVer, state.AgentVersion)
-	require.Equal(t, "kea", state.Apps[0].Type)
+	require.Equal(t, AppTypeKea, state.Apps[0].Type)
 }
 
 // Test that a command can be successfully forwarded to Kea and the response
@@ -104,7 +113,7 @@ func TestForwardToKeaOverHTTP(t *testing.T) {
 	require.NoError(t, cmdsResult.CmdsErrors[0])
 
 	responseList := actualResponse
-	require.Equal(t, 2, len(responseList))
+	require.Len(t, responseList, 2)
 
 	require.Equal(t, 1, responseList[0].Result)
 	require.Equal(t, "operation failed", responseList[0].Text)
@@ -113,7 +122,7 @@ func TestForwardToKeaOverHTTP(t *testing.T) {
 	require.Equal(t, 0, responseList[1].Result)
 	require.Equal(t, "operation succeeded", responseList[1].Text)
 	require.NotNil(t, responseList[1].Arguments)
-	require.Equal(t, 1, len(*responseList[1].Arguments))
+	require.Len(t, *responseList[1].Arguments, 1)
 	require.Contains(t, *responseList[1].Arguments, "success")
 }
 
@@ -173,7 +182,7 @@ func TestForwardToKeaOverHTTPWith2Cmds(t *testing.T) {
 	require.NoError(t, cmdsResult.CmdsErrors[1])
 
 	responseList := actualResponse1
-	require.Equal(t, 2, len(responseList))
+	require.Len(t, responseList, 2)
 
 	require.Equal(t, 1, responseList[0].Result)
 	require.Equal(t, "operation failed", responseList[0].Text)
@@ -182,11 +191,11 @@ func TestForwardToKeaOverHTTPWith2Cmds(t *testing.T) {
 	require.Equal(t, 0, responseList[1].Result)
 	require.Equal(t, "operation succeeded", responseList[1].Text)
 	require.NotNil(t, responseList[1].Arguments)
-	require.Equal(t, 1, len(*responseList[1].Arguments))
+	require.Len(t, *responseList[1].Arguments, 1)
 	require.Contains(t, *responseList[1].Arguments, "success")
 
 	responseList = actualResponse2
-	require.Equal(t, 1, len(responseList))
+	require.Len(t, responseList, 1)
 
 	require.Equal(t, 1, responseList[0].Result)
 	require.Equal(t, "operation failed", responseList[0].Text)
@@ -228,6 +237,75 @@ func TestForwardToKeaOverHTTPInvalidResponse(t *testing.T) {
 	require.Error(t, cmdsResult.CmdsErrors[0])
 }
 
+// Test that a statistics request can be successfully forwarded to named
+// statistics-channel and the output can be parsed.
+func TestForwardToNamedStats(t *testing.T) {
+	mockAgentClient, agents, teardown := setupGrpcliTestCase(t)
+	defer teardown()
+
+	rsp := agentapi.ForwardToNamedStatsRsp{
+		Status: &agentapi.Status{
+			Code: 0,
+		},
+		NamedStatsResponse: &agentapi.NamedStatsResponse{
+			Status: &agentapi.Status{
+				Code: 0,
+			},
+			Response: `{
+                             "json-stats-version": "1.2.",
+                             "views": {
+                                 "_default": {
+                                     "resolver": {
+                                         "cachestats": {
+                                             "CacheHits": 11,
+                                             "CacheMisses": 12
+                                         }
+                                     }
+                                 }
+                             }
+                        }`,
+		},
+	}
+
+	mockAgentClient.EXPECT().ForwardToNamedStats(gomock.Any(), gomock.Any()).
+		Return(&rsp, nil)
+
+	ctx := context.Background()
+	actualResponse := NamedStatsGetResponse{}
+	err := agents.ForwardToNamedStats(ctx, "127.0.0.1", 8080, "http://localhost:8000/", &actualResponse)
+	require.NoError(t, err)
+	require.NotNil(t, actualResponse)
+	require.Len(t, *actualResponse.Views, 1)
+	require.Contains(t, *actualResponse.Views, "_default")
+}
+
+// Test that the error is returned when the response to the forwarded
+// named statistics request is malformed.
+func TestForwardToNamedStatsInvalidResponse(t *testing.T) {
+	mockAgentClient, agents, teardown := setupGrpcliTestCase(t)
+	defer teardown()
+
+	rsp := agentapi.ForwardToNamedStatsRsp{
+		Status: &agentapi.Status{
+			Code: 0,
+		},
+		NamedStatsResponse: &agentapi.NamedStatsResponse{
+			Status: &agentapi.Status{
+				Code: 0,
+			},
+			Response: `{
+                          "views": "not the views you are looking for",
+            }`},
+	}
+	mockAgentClient.EXPECT().ForwardToNamedStats(gomock.Any(), gomock.Any()).
+		Return(&rsp, nil)
+
+	ctx := context.Background()
+	actualResponse := NamedStatsGetResponse{}
+	err := agents.ForwardToNamedStats(ctx, "127.0.0.1", 8080, "http://localhost:8000/", &actualResponse)
+	require.Error(t, err)
+}
+
 // Test that a command can be successfully forwarded to rndc and the response
 // can be parsed.
 func TestForwardRndcCommand(t *testing.T) {
@@ -235,9 +313,9 @@ func TestForwardRndcCommand(t *testing.T) {
 	defer teardown()
 
 	rndcSettings := Bind9Control{
-		CtrlAddress: "127.0.0.1",
-		CtrlPort:    953,
-		CtrlKey:     "",
+		Address: "127.0.0.1",
+		Port:    953,
+		Key:     "",
 	}
 
 	rsp := agentapi.ForwardRndcCommandRsp{
