@@ -9,18 +9,22 @@ import (
 
 	"isc.org/stork/server/agentcomm"
 	dbmodel "isc.org/stork/server/database/model"
+	"isc.org/stork/server/eventcenter"
 	storkutil "isc.org/stork/util"
 )
 
 type StatsPuller struct {
 	*agentcomm.PeriodicPuller
+	EventCenter eventcenter.EventCenter
 }
 
 // Create a StatsPuller object that in background pulls BIND 9 statistics.
 // Beneath it spawns a goroutine that pulls stats periodically from the BIND 9
 // statistics-channel.
-func NewStatsPuller(db *pg.DB, agents agentcomm.ConnectedAgents) (*StatsPuller, error) {
-	statsPuller := &StatsPuller{}
+func NewStatsPuller(db *pg.DB, agents agentcomm.ConnectedAgents, eventCenter eventcenter.EventCenter) (*StatsPuller, error) {
+	statsPuller := &StatsPuller{
+		EventCenter: eventCenter,
+	}
 	periodicPuller, err := agentcomm.NewPeriodicPuller(db, agents, "BIND 9 Stats", "bind9_stats_puller_interval",
 		statsPuller.pullStats)
 	if err != nil {
@@ -70,7 +74,7 @@ func (statsPuller *StatsPuller) getStatsFromApp(dbApp *dbmodel.App) error {
 		return err
 	}
 	statsAddress := storkutil.HostWithPortURL(statsChannel.Address, statsChannel.Port)
-	statsRequest := "json/v1/server"
+	statsRequest := "json/v1"
 	statsURL := fmt.Sprintf("%s%s", statsAddress, statsRequest)
 
 	statsOutput := NamedStatsGetResponse{}
@@ -80,28 +84,34 @@ func (statsPuller *StatsPuller) getStatsFromApp(dbApp *dbmodel.App) error {
 		return err
 	}
 
+	namedStats := &dbmodel.Bind9NamedStats{}
+
 	if statsOutput.Views != nil {
+		viewStats := make(map[string]*dbmodel.Bind9StatsView)
+
 		for name, view := range statsOutput.Views {
 			// Only deal with the default view for now.
 			if name != "_default" {
 				continue
 			}
-			// Calculate the cache hit ratio: the number of
-			// responses that were retrieved from cache divided
-			// by the number of all responses.
-			hits := view.Resolver.CacheStats.CacheHits
-			misses := view.Resolver.CacheStats.CacheMisses
-			ratio := float64(0)
-			total := float64(hits) + float64(misses)
-			if total != 0 {
-				ratio = float64(hits) / total
+
+			cacheStats := make(map[string]int64)
+			cacheStats["CacheHits"] = view.Resolver.CacheStats.CacheHits
+			cacheStats["CacheMisses"] = view.Resolver.CacheStats.CacheMisses
+			cacheStats["QueryHits"] = view.Resolver.CacheStats.QueryHits
+			cacheStats["QueryMisses"] = view.Resolver.CacheStats.QueryMisses
+
+			viewStats[name] = &dbmodel.Bind9StatsView{
+				Resolver: &dbmodel.Bind9StatsResolver{
+					CacheStats: cacheStats,
+				},
 			}
-			dbApp.Daemons[0].Bind9Daemon.Stats.CacheHitRatio = ratio
-			dbApp.Daemons[0].Bind9Daemon.Stats.CacheHits = hits
-			dbApp.Daemons[0].Bind9Daemon.Stats.CacheMisses = misses
 			break
 		}
+
+		namedStats.Views = viewStats
 	}
 
-	return CommitAppIntoDB(statsPuller.Db, dbApp)
+	dbApp.Daemons[0].Bind9Daemon.Stats.NamedStats = namedStats
+	return dbmodel.UpdateDaemon(statsPuller.Db, dbApp.Daemons[0])
 }
