@@ -68,6 +68,7 @@ func GetMachineByAddressAndAgentPort(db *pg.DB, address string, agentPort int64)
 func GetMachineByID(db *pg.DB, id int64) (*Machine, error) {
 	machine := Machine{}
 	q := db.Model(&machine).Where("machine.id = ?", id)
+	q = q.Relation("Apps.Daemons")
 	q = q.Relation("Apps.AccessPoints")
 	err := q.Select()
 	if err == pg.ErrNoRows {
@@ -134,6 +135,9 @@ func GetMachinesByPage(db *pg.DB, offset int64, limit int64, filterText *string,
 
 	total, err := q.SelectAndCount()
 	if err != nil {
+		if err == pg.ErrNoRows {
+			return []Machine{}, 0, nil
+		}
 		return nil, 0, errors.Wrapf(err, "problem with getting machines")
 	}
 
