@@ -13,6 +13,7 @@ import (
 
 // Generates a bunch of users and stores them in the database.
 func generateTestUsers(t *testing.T, db *dbops.PgDB) {
+	faker.Seed(1)
 	for i := 0; i < 100; i++ {
 		login := faker.Word()
 		login = fmt.Sprintf("%s%d", login, i)
@@ -251,7 +252,7 @@ func TestGetUsers(t *testing.T) {
 
 	generateTestUsers(t, db)
 
-	users, total, err := GetUsers(db, 0, 1000, SystemUserOrderByID)
+	users, total, err := GetUsersByPage(db, 0, 1000, nil, "", SortDirAny)
 	require.NoError(t, err)
 	require.Len(t, users, 101)
 	require.EqualValues(t, 101, total)
@@ -264,14 +265,14 @@ func TestGetUsers(t *testing.T) {
 	}
 }
 
-// Tests that users can be fetched and sorted by login or email.
-func TestGetUsersSortByLoginEmail(t *testing.T) {
+// Tests that users can be fetched and sorted by login.
+func TestGetUsersSortByLogin(t *testing.T) {
 	db, _, teardown := dbtest.SetupDatabaseTestCase(t)
 	defer teardown()
 
 	generateTestUsers(t, db)
 
-	users, total, err := GetUsers(db, 0, 1000, SystemUserOrderByLoginEmail)
+	users, total, err := GetUsersByPage(db, 0, 1000, nil, "login", SortDirAsc)
 	require.NoError(t, err)
 	require.Len(t, users, 101)
 	require.EqualValues(t, 101, total)
@@ -291,7 +292,7 @@ func TestGetUsersPage(t *testing.T) {
 
 	generateTestUsers(t, db)
 
-	users, total, err := GetUsers(db, 50, 10, SystemUserOrderByID)
+	users, total, err := GetUsersByPage(db, 50, 10, nil, "", SortDirAny)
 	require.NoError(t, err)
 	require.Len(t, users, 10)
 	require.EqualValues(t, 51, users[0].ID)
@@ -312,7 +313,7 @@ func TestGetUsersLastPage(t *testing.T) {
 
 	generateTestUsers(t, db)
 
-	users, total, err := GetUsers(db, 90, 20, SystemUserOrderByID)
+	users, total, err := GetUsersByPage(db, 90, 20, nil, "", SortDirAny)
 	require.NoError(t, err)
 	require.Len(t, users, 11)
 	require.EqualValues(t, 91, users[0].ID)
@@ -326,6 +327,24 @@ func TestGetUsersLastPage(t *testing.T) {
 	}
 }
 
+// Check filtering users by text.
+func TestGetUsersPageByText(t *testing.T) {
+	db, _, teardown := dbtest.SetupDatabaseTestCase(t)
+	defer teardown()
+
+	generateTestUsers(t, db)
+
+	text := "3"
+	users, total, err := GetUsersByPage(db, 0, 100, &text, "", SortDirAny)
+	require.NoError(t, err)
+	require.Len(t, users, 19)
+	require.EqualValues(t, 19, total)
+	require.EqualValues(t, "ut3", users[0].Login)
+	require.EqualValues(t, "qui32", users[5].Login)
+	require.EqualValues(t, "ut37", users[10].Login)
+	require.EqualValues(t, "est93", users[18].Login)
+}
+
 // Tests that user can be fetched by Id.
 func TestGetUserByID(t *testing.T) {
 	db, _, teardown := dbtest.SetupDatabaseTestCase(t)
@@ -333,7 +352,7 @@ func TestGetUserByID(t *testing.T) {
 
 	generateTestUsers(t, db)
 
-	users, total, err := GetUsers(db, 0, 1000, SystemUserOrderByID)
+	users, total, err := GetUsersByPage(db, 0, 1000, nil, "", SortDirAny)
 	require.NoError(t, err)
 	require.EqualValues(t, 101, total)
 
@@ -359,11 +378,11 @@ func TestUserGroups(t *testing.T) {
 		Lastname: "Smith",
 		Name:     "John",
 		Password: "pass",
-		Groups: SystemGroups{
-			&SystemGroup{
+		Groups: []*SystemGroup{
+			{
 				ID: 1,
 			},
-			&SystemGroup{
+			{
 				ID: 2,
 			},
 		},
@@ -388,8 +407,8 @@ func TestUserGroups(t *testing.T) {
 	require.True(t, returned.InGroup(&SystemGroup{Name: "admin"}))
 
 	// Remove the user from one of the groups.
-	user.Groups = SystemGroups{
-		&SystemGroup{
+	user.Groups = []*SystemGroup{
+		{
 			ID: 2,
 		},
 	}
