@@ -62,6 +62,7 @@ func addTestHosts(t *testing.T, db *pg.DB) (hosts []dbmodel.Host, apps []dbmodel
 	hosts = []dbmodel.Host{
 		{
 			SubnetID: 1,
+			Hostname: "first.example.org",
 			HostIdentifiers: []dbmodel.HostIdentifier{
 				{
 					Type:  "hw-address",
@@ -146,7 +147,7 @@ func addTestHosts(t *testing.T, db *pg.DB) (hosts []dbmodel.Host, apps []dbmodel
 	// Add apps to the database.
 	for i, a := range apps {
 		app := a
-		err := dbmodel.AddApp(db, &app)
+		_, err := dbmodel.AddApp(db, &app)
 		require.NoError(t, err)
 		require.NotZero(t, app.ID)
 		apps[i] = app
@@ -170,7 +171,8 @@ func TestGetHostsNoFiltering(t *testing.T) {
 
 	settings := RestAPISettings{}
 	fa := storktest.NewFakeAgents(nil, nil)
-	rapi, err := NewRestAPI(&settings, dbSettings, db, fa)
+	fec := &storktest.FakeEventCenter{}
+	rapi, err := NewRestAPI(&settings, dbSettings, db, fa, fec)
 	require.NoError(t, err)
 	ctx := context.Background()
 
@@ -237,6 +239,9 @@ func TestGetHostsNoFiltering(t *testing.T) {
 	require.Empty(t, items[3].SubnetPrefix)
 	require.Empty(t, items[4].SubnetPrefix)
 
+	// Hosts
+	require.Equal(t, "first.example.org", items[0].Hostname)
+
 	// The first host should be associated with two apps.
 	require.Len(t, items[0].LocalHosts, 2)
 	require.NotNil(t, items[0].LocalHosts[0])
@@ -256,7 +261,8 @@ func TestGetHostsBySubnetID(t *testing.T) {
 
 	settings := RestAPISettings{}
 	fa := storktest.NewFakeAgents(nil, nil)
-	rapi, err := NewRestAPI(&settings, dbSettings, db, fa)
+	fec := &storktest.FakeEventCenter{}
+	rapi, err := NewRestAPI(&settings, dbSettings, db, fa, fec)
 	require.NoError(t, err)
 	ctx := context.Background()
 
@@ -281,7 +287,8 @@ func TestGetHostsWithFiltering(t *testing.T) {
 
 	settings := RestAPISettings{}
 	fa := storktest.NewFakeAgents(nil, nil)
-	rapi, err := NewRestAPI(&settings, dbSettings, db, fa)
+	fec := &storktest.FakeEventCenter{}
+	rapi, err := NewRestAPI(&settings, dbSettings, db, fa, fec)
 	require.NoError(t, err)
 	ctx := context.Background()
 
