@@ -19,6 +19,7 @@ import (
 	"isc.org/stork/server/apps/kea"
 	dbops "isc.org/stork/server/database"
 	dbmodel "isc.org/stork/server/database/model"
+	"isc.org/stork/server/eventcenter"
 	"isc.org/stork/server/gen/models"
 	dhcp "isc.org/stork/server/gen/restapi/operations/d_h_c_p"
 	"isc.org/stork/server/gen/restapi/operations/general"
@@ -122,7 +123,7 @@ func appCompare(dbApp *dbmodel.App, app *agentcomm.App) bool {
 	return controlPortEqual
 }
 
-func getMachineAndAppsState(ctx context.Context, db *dbops.PgDB, dbMachine *dbmodel.Machine, agents agentcomm.ConnectedAgents) string {
+func getMachineAndAppsState(ctx context.Context, db *dbops.PgDB, dbMachine *dbmodel.Machine, agents agentcomm.ConnectedAgents, eventCenter eventcenter.EventCenter) string {
 	ctx2, cancel := context.WithTimeout(ctx, 10*time.Second)
 	defer cancel()
 
@@ -147,8 +148,13 @@ func getMachineAndAppsState(ctx context.Context, db *dbops.PgDB, dbMachine *dbmo
 	}
 
 	// If there are any new apps then get their state and add to db.
-	// Old ones are just updated.
-	oldAppsList := dbMachine.Apps
+	// Old ones are just updated. Use GetAppsByMachine to retrieve
+	// machine's apps with their daemons.
+	oldAppsList, err := dbmodel.GetAppsByMachine(db, dbMachine.ID)
+	if err != nil {
+		log.Error(err)
+		return "cannot get machine's apps from db"
+	}
 	dbMachine.Apps = []*dbmodel.App{}
 	for _, app := range state.Apps {
 		// look for old app
@@ -185,17 +191,17 @@ func getMachineAndAppsState(ctx context.Context, db *dbops.PgDB, dbMachine *dbmo
 
 		switch app.Type {
 		case dbmodel.AppTypeKea:
-			kea.GetAppState(ctx2, agents, dbApp)
-			err = kea.CommitAppIntoDB(db, dbApp)
+			events := kea.GetAppState(ctx2, agents, dbApp)
+			err = kea.CommitAppIntoDB(db, dbApp, eventCenter, events)
 		case dbmodel.AppTypeBind9:
 			bind9.GetAppState(ctx2, agents, dbApp)
-			err = bind9.CommitAppIntoDB(db, dbApp)
+			err = bind9.CommitAppIntoDB(db, dbApp, eventCenter)
 		default:
 			err = nil
 		}
 
 		if err != nil {
-			log.Error(err)
+			log.Errorf("cannot store application state: %+v", err)
 			return "problem with storing application state in the database"
 		}
 
@@ -246,7 +252,7 @@ func (r *RestAPI) GetMachineState(ctx context.Context, params services.GetMachin
 		return rsp
 	}
 
-	errStr := getMachineAndAppsState(ctx, r.Db, dbMachine, r.Agents)
+	errStr := getMachineAndAppsState(ctx, r.Db, dbMachine, r.Agents, r.EventCenter)
 	if errStr != "" {
 		rsp := services.NewGetMachineStateDefault(http.StatusInternalServerError).WithPayload(&models.APIError{
 			Message: &errStr,
@@ -383,9 +389,10 @@ func (r *RestAPI) CreateMachine(ctx context.Context, params services.CreateMachi
 			})
 			return rsp
 		}
+		r.EventCenter.AddInfoEvent("added {machine}", dbMachine)
 	}
 
-	errStr := getMachineAndAppsState(ctx, r.Db, dbMachine, r.Agents)
+	errStr := getMachineAndAppsState(ctx, r.Db, dbMachine, r.Agents, r.EventCenter)
 	if errStr != "" {
 		rsp := services.NewCreateMachineDefault(http.StatusInternalServerError).WithPayload(&models.APIError{
 			Message: &errStr,
@@ -519,6 +526,8 @@ func (r *RestAPI) DeleteMachine(ctx context.Context, params services.DeleteMachi
 		return rsp
 	}
 
+	r.EventCenter.AddInfoEvent("removed {machine}", dbMachine)
+
 	rsp := services.NewDeleteMachineOK()
 
 	return rsp
@@ -587,6 +596,22 @@ func appToRestAPI(dbApp *dbmodel.App) *models.App {
 	}
 
 	if isBind9App {
+		var queryHitRatio float64
+		var queryHits int64
+		var queryMisses int64
+		namedStats := dbApp.Daemons[0].Bind9Daemon.Stats.NamedStats
+		if namedStats != nil {
+			view, okView := namedStats.Views["_default"]
+			if okView {
+				queryHits = view.Resolver.CacheStats["QueryHits"]
+				queryMisses = view.Resolver.CacheStats["QueryMisses"]
+				queryTotal := float64(queryHits) + float64(queryMisses)
+				if queryTotal > 0 {
+					queryHitRatio = float64(queryHits) / queryTotal
+				}
+			}
+		}
+
 		bind9Daemon := &models.Bind9Daemon{
 			Pid:           int64(dbApp.Daemons[0].Pid),
 			Name:          dbApp.Daemons[0].Name,
@@ -596,9 +621,9 @@ func appToRestAPI(dbApp *dbmodel.App) *models.App {
 			ReloadedAt:    strfmt.DateTime(dbApp.Daemons[0].ReloadedAt),
 			ZoneCount:     dbApp.Daemons[0].Bind9Daemon.Stats.ZoneCount,
 			AutoZoneCount: dbApp.Daemons[0].Bind9Daemon.Stats.AutomaticZoneCount,
-			CacheHits:     dbApp.Daemons[0].Bind9Daemon.Stats.CacheHits,
-			CacheMisses:   dbApp.Daemons[0].Bind9Daemon.Stats.CacheMisses,
-			CacheHitRatio: dbApp.Daemons[0].Bind9Daemon.Stats.CacheHitRatio,
+			QueryHits:     queryHits,
+			QueryMisses:   queryMisses,
+			QueryHitRatio: queryHitRatio,
 		}
 
 		app.Details = struct {
@@ -784,33 +809,61 @@ func (r *RestAPI) GetAppServicesStatus(ctx context.Context, params services.GetA
 					appID[1] = s.Daemons[i].App.ID
 				}
 			}
+			// Get the communication state value.
+			commInterrupted := make([]int64, 2)
+			for i, c := range []*bool{ha.PrimaryCommInterrupted, ha.SecondaryCommInterrupted} {
+				if c == nil {
+					// Negative value indicates that the communication state is unknown.
+					// Quite possibly that we're running earlier Kea version that doesn't
+					// provide this information.
+					commInterrupted[i] = -1
+				} else if *c {
+					// Communication interrupted.
+					commInterrupted[i] = 1
+				}
+			}
 			keaStatus.HaServers = &models.KeaStatusHaServers{
 				PrimaryServer: &models.KeaHAServerStatus{
-					Age:            age[0],
-					AppID:          appID[0],
-					ControlAddress: controlAddress[0],
-					FailoverTime:   failoverTime[0],
-					ID:             ha.PrimaryID,
-					InTouch:        ha.PrimaryReachable,
-					Role:           "primary",
-					Scopes:         ha.PrimaryLastScopes,
-					State:          ha.PrimaryLastState,
-					StatusTime:     statusTime[0],
-				},
-				SecondaryServer: &models.KeaHAServerStatus{
-					Age:            age[1],
-					AppID:          appID[1],
-					ControlAddress: controlAddress[1],
-					FailoverTime:   failoverTime[1],
-					ID:             ha.SecondaryID,
-					InTouch:        ha.SecondaryReachable,
-					Role:           secondaryRole,
-					Scopes:         ha.SecondaryLastScopes,
-					State:          ha.SecondaryLastState,
-					StatusTime:     statusTime[1],
+					Age:                age[0],
+					AppID:              appID[0],
+					ControlAddress:     controlAddress[0],
+					FailoverTime:       failoverTime[0],
+					ID:                 ha.PrimaryID,
+					InTouch:            ha.PrimaryReachable,
+					Role:               "primary",
+					Scopes:             ha.PrimaryLastScopes,
+					State:              ha.PrimaryLastState,
+					StatusTime:         statusTime[0],
+					CommInterrupted:    commInterrupted[0],
+					ConnectingClients:  ha.PrimaryConnectingClients,
+					UnackedClients:     ha.PrimaryUnackedClients,
+					UnackedClientsLeft: ha.PrimaryUnackedClientsLeft,
+					AnalyzedPackets:    ha.PrimaryAnalyzedPackets,
 				},
 			}
 
+			// Including the information about the secondary server only
+			// makes sense for load-balancing and hot-standby mode.
+			if ha.HAMode != "passive-backup" {
+				keaStatus.HaServers.SecondaryServer = &models.KeaHAServerStatus{
+					Age:                age[1],
+					AppID:              appID[1],
+					ControlAddress:     controlAddress[1],
+					FailoverTime:       failoverTime[1],
+					ID:                 ha.SecondaryID,
+					InTouch:            ha.SecondaryReachable,
+					Role:               secondaryRole,
+					Scopes:             ha.SecondaryLastScopes,
+					State:              ha.SecondaryLastState,
+					StatusTime:         statusTime[1],
+					CommInterrupted:    commInterrupted[1],
+					ConnectingClients:  ha.SecondaryConnectingClients,
+					UnackedClients:     ha.SecondaryUnackedClients,
+					UnackedClientsLeft: ha.SecondaryUnackedClientsLeft,
+					AnalyzedPackets:    ha.SecondaryAnalyzedPackets,
+				}
+			}
+
 			serviceStatus := &models.ServiceStatus{
 				Status: struct {
 					models.KeaStatus
@@ -953,9 +1006,15 @@ func (r *RestAPI) GetDhcpOverview(ctx context.Context, params dhcp.GetDhcpOvervi
 			// or integrate ISC DHCP with Stork, the number of HA states returned
 			// will be 0 or 1. Therefore, we take the first HA state if it exists
 			// and return it over the REST API.
-			haState := ""
-			if haStates := dbDaemon.GetHAStateNames(); len(haStates) > 0 {
-				haState = haStates[0]
+			var (
+				haState     string
+				haFailureAt strfmt.DateTime
+			)
+			if haOverview := dbDaemon.GetHAOverview(); len(haOverview) > 0 {
+				haState = haOverview[0].State
+				if !haOverview[0].LastFailureAt.IsZero() {
+					haFailureAt = strfmt.DateTime(haOverview[0].LastFailureAt)
+				}
 			}
 			daemon := &models.DhcpDaemon{
 				MachineID:       dbApp.MachineID,
@@ -968,6 +1027,7 @@ func (r *RestAPI) GetDhcpOverview(ctx context.Context, params dhcp.GetDhcpOvervi
 				Lps24h:          0,
 				AddrUtilization: 0,
 				HaState:         haState,
+				HaFailureAt:     haFailureAt,
 				Uptime:          dbDaemon.Uptime,
 			}
 			dhcpDaemons = append(dhcpDaemons, daemon)
