@@ -36,7 +36,8 @@ func TestGetVersion(t *testing.T) {
 
 	settings := RestAPISettings{}
 	fa := storktest.NewFakeAgents(nil, nil)
-	rapi, err := NewRestAPI(&settings, dbSettings, db, fa)
+	fec := &storktest.FakeEventCenter{}
+	rapi, err := NewRestAPI(&settings, dbSettings, db, fa, fec)
 	require.NoError(t, err)
 	ctx := context.Background()
 
@@ -54,7 +55,8 @@ func TestGetMachineStateOnly(t *testing.T) {
 
 	settings := RestAPISettings{}
 	fa := storktest.NewFakeAgents(nil, nil)
-	rapi, err := NewRestAPI(&settings, dbSettings, db, fa)
+	fec := &storktest.FakeEventCenter{}
+	rapi, err := NewRestAPI(&settings, dbSettings, db, fa, fec)
 	require.NoError(t, err)
 	ctx := context.Background()
 
@@ -182,7 +184,8 @@ func TestGetMachineAndAppsState(t *testing.T) {
 
 	settings := RestAPISettings{}
 	fa := storktest.NewFakeAgents(mockGetAppsState, nil)
-	rapi, err := NewRestAPI(&settings, dbSettings, db, fa)
+	fec := &storktest.FakeEventCenter{}
+	rapi, err := NewRestAPI(&settings, dbSettings, db, fa, fec)
 	require.NoError(t, err)
 	ctx := context.Background()
 
@@ -203,7 +206,7 @@ func TestGetMachineAndAppsState(t *testing.T) {
 		Type:         dbmodel.AppTypeKea,
 		AccessPoints: keaPoints,
 	}
-	err = dbmodel.AddApp(db, keaApp)
+	_, err = dbmodel.AddApp(db, keaApp)
 	require.NoError(t, err)
 	m.Apps = append(m.Apps, keaApp)
 
@@ -216,7 +219,7 @@ func TestGetMachineAndAppsState(t *testing.T) {
 		Type:         dbmodel.AppTypeBind9,
 		AccessPoints: bind9Points,
 	}
-	err = dbmodel.AddApp(db, bind9App)
+	_, err = dbmodel.AddApp(db, bind9App)
 	require.NoError(t, err)
 	m.Apps = append(m.Apps, bind9App)
 
@@ -251,7 +254,8 @@ func TestCreateMachine(t *testing.T) {
 
 	settings := RestAPISettings{}
 	fa := storktest.NewFakeAgents(nil, nil)
-	rapi, err := NewRestAPI(&settings, dbSettings, db, fa)
+	fec := &storktest.FakeEventCenter{}
+	rapi, err := NewRestAPI(&settings, dbSettings, db, fa, fec)
 	require.NoError(t, err)
 	ctx := context.Background()
 
@@ -307,7 +311,8 @@ func TestGetMachines(t *testing.T) {
 
 	settings := RestAPISettings{}
 	fa := storktest.NewFakeAgents(nil, nil)
-	rapi, err := NewRestAPI(&settings, dbSettings, db, fa)
+	fec := &storktest.FakeEventCenter{}
+	rapi, err := NewRestAPI(&settings, dbSettings, db, fa, fec)
 	require.NoError(t, err)
 	ctx := context.Background()
 
@@ -329,7 +334,8 @@ func TestGetMachine(t *testing.T) {
 
 	settings := RestAPISettings{}
 	fa := storktest.NewFakeAgents(nil, nil)
-	rapi, err := NewRestAPI(&settings, dbSettings, db, fa)
+	fec := &storktest.FakeEventCenter{}
+	rapi, err := NewRestAPI(&settings, dbSettings, db, fa, fec)
 	require.NoError(t, err)
 	ctx := context.Background()
 
@@ -379,7 +385,7 @@ func TestGetMachine(t *testing.T) {
 		AccessPoints: accessPoints,
 		Daemons:      []*dbmodel.Daemon{},
 	}
-	err = dbmodel.AddApp(db, s)
+	_, err = dbmodel.AddApp(db, s)
 	require.NoError(t, err)
 	require.NotEqual(t, 0, s.ID)
 
@@ -401,7 +407,8 @@ func TestUpdateMachine(t *testing.T) {
 
 	settings := RestAPISettings{}
 	fa := storktest.NewFakeAgents(nil, nil)
-	rapi, err := NewRestAPI(&settings, dbSettings, db, fa)
+	fec := &storktest.FakeEventCenter{}
+	rapi, err := NewRestAPI(&settings, dbSettings, db, fa, fec)
 	require.NoError(t, err)
 	ctx := context.Background()
 
@@ -485,7 +492,8 @@ func TestDeleteMachine(t *testing.T) {
 
 	settings := RestAPISettings{}
 	fa := storktest.NewFakeAgents(nil, nil)
-	rapi, err := NewRestAPI(&settings, dbSettings, db, fa)
+	fec := &storktest.FakeEventCenter{}
+	rapi, err := NewRestAPI(&settings, dbSettings, db, fa, fec)
 	require.NoError(t, err)
 	ctx := context.Background()
 
@@ -536,7 +544,8 @@ func TestGetApp(t *testing.T) {
 
 	settings := RestAPISettings{}
 	fa := storktest.NewFakeAgents(nil, nil)
-	rapi, err := NewRestAPI(&settings, dbSettings, db, fa)
+	fec := &storktest.FakeEventCenter{}
+	rapi, err := NewRestAPI(&settings, dbSettings, db, fa, fec)
 	require.NoError(t, err)
 	ctx := context.Background()
 
@@ -569,7 +578,7 @@ func TestGetApp(t *testing.T) {
 		AccessPoints: accessPoints,
 		Daemons:      []*dbmodel.Daemon{},
 	}
-	err = dbmodel.AddApp(db, s)
+	_, err = dbmodel.AddApp(db, s)
 	require.NoError(t, err)
 
 	// get added app
@@ -588,7 +597,8 @@ func TestRestGetApp(t *testing.T) {
 
 	settings := RestAPISettings{}
 	fa := storktest.NewFakeAgents(nil, nil)
-	rapi, err := NewRestAPI(&settings, dbSettings, db, fa)
+	fec := &storktest.FakeEventCenter{}
+	rapi, err := NewRestAPI(&settings, dbSettings, db, fa, fec)
 	require.NoError(t, err)
 	ctx := context.Background()
 
@@ -621,7 +631,7 @@ func TestRestGetApp(t *testing.T) {
 		AccessPoints: keaPoints,
 		Daemons:      []*dbmodel.Daemon{},
 	}
-	err = dbmodel.AddApp(db, keaApp)
+	_, err = dbmodel.AddApp(db, keaApp)
 	require.NoError(t, err)
 
 	// get added kea app
@@ -648,7 +658,7 @@ func TestRestGetApp(t *testing.T) {
 			},
 		},
 	}
-	err = dbmodel.AddApp(db, bind9App)
+	_, err = dbmodel.AddApp(db, bind9App)
 	require.NoError(t, err)
 
 	// get added BIND 9 app
@@ -667,7 +677,8 @@ func TestRestGetApps(t *testing.T) {
 
 	settings := RestAPISettings{}
 	fa := storktest.NewFakeAgents(nil, nil)
-	rapi, err := NewRestAPI(&settings, dbSettings, db, fa)
+	fec := &storktest.FakeEventCenter{}
+	rapi, err := NewRestAPI(&settings, dbSettings, db, fa, fec)
 	require.NoError(t, err)
 	ctx := context.Background()
 
@@ -701,7 +712,7 @@ func TestRestGetApps(t *testing.T) {
 			},
 		},
 	}
-	err = dbmodel.AddApp(db, s1)
+	_, err = dbmodel.AddApp(db, s1)
 	require.NoError(t, err)
 
 	// add app BIND 9 to machine
@@ -719,7 +730,7 @@ func TestRestGetApps(t *testing.T) {
 			},
 		},
 	}
-	err = dbmodel.AddApp(db, s2)
+	_, err = dbmodel.AddApp(db, s2)
 	require.NoError(t, err)
 
 	// get added apps
@@ -730,65 +741,6 @@ func TestRestGetApps(t *testing.T) {
 	require.EqualValues(t, 2, okRsp.Payload.Total)
 }
 
-// Generates a response to the status-get command including two status
-// structures, one for DHCPv4 and one for DHCPv6. Both contain HA
-// status information.
-func mockGetStatusWithHA(callNo int, cmdResponses []interface{}) {
-	daemons, _ := agentcomm.NewKeaDaemons("dhcp4", "dhcp6")
-	command, _ := agentcomm.NewKeaCommand("status-get", daemons, nil)
-	json := `[
-        {
-            "result": 0,
-            "text": "Everything is fine",
-            "arguments": {
-                "pid": 1234,
-                "uptime": 3024,
-                "reload": 1111,
-                "ha-servers":
-                    {
-                        "local": {
-                            "role": "primary",
-                            "scopes": [ "server1" ],
-                            "state": "load-balancing"
-                        },
-                        "remote": {
-                            "age": 10,
-                            "in-touch": true,
-                            "role": "secondary",
-                            "last-scopes": [ "server2" ],
-                            "last-state": "load-balancing"
-                        }
-                    }
-              }
-         },
-         {
-             "result": 0,
-             "text": "Everything is fine",
-             "arguments": {
-                 "pid": 2345,
-                 "uptime": 3333,
-                 "reload": 2222,
-                 "ha-servers":
-                     {
-                         "local": {
-                             "role": "primary",
-                             "scopes": [ "server1" ],
-                             "state": "hot-standby"
-                         },
-                         "remote": {
-                             "age": 3,
-                             "in-touch": true,
-                             "role": "standby",
-                             "last-scopes": [ ],
-                             "last-state": "waiting"
-                         }
-                     }
-               }
-          }
-    ]`
-	_ = agentcomm.UnmarshalKeaResponseList(command, json, cmdResponses[0])
-}
-
 // Test that status of two HA services for a Kea application is parsed
 // correctly.
 func TestRestGetAppServicesStatus(t *testing.T) {
@@ -798,8 +750,9 @@ func TestRestGetAppServicesStatus(t *testing.T) {
 	settings := RestAPISettings{}
 	// Configure the fake control agents to mimic returning a status of
 	// two HA services for Kea.
-	fa := storktest.NewFakeAgents(mockGetStatusWithHA, nil)
-	rapi, err := NewRestAPI(&settings, dbSettings, db, fa)
+	fa := storktest.NewFakeAgents(nil, nil)
+	fec := &storktest.FakeEventCenter{}
+	rapi, err := NewRestAPI(&settings, dbSettings, db, fa, fec)
 	require.NoError(t, err)
 	ctx := context.Background()
 
@@ -824,28 +777,39 @@ func TestRestGetAppServicesStatus(t *testing.T) {
 			dbmodel.NewKeaDaemon("dhcp4", true),
 		},
 	}
-	err = dbmodel.AddApp(db, keaApp)
+	_, err = dbmodel.AddApp(db, keaApp)
 	require.NoError(t, err)
 	require.NotZero(t, keaApp.ID)
 
 	exampleTime := storkutil.UTCNow().Add(-5 * time.Second)
+	commInterrupted := []bool{true, true}
 	keaServices := []dbmodel.Service{
 		{
 			BaseService: dbmodel.BaseService{
 				ServiceType: "ha_dhcp",
 			},
 			HAService: &dbmodel.BaseHAService{
-				HAType:                     "dhcp4",
-				HAMode:                     "load-balancing",
-				PrimaryID:                  keaApp.ID,
-				PrimaryStatusCollectedAt:   exampleTime,
-				SecondaryStatusCollectedAt: exampleTime,
-				PrimaryLastState:           "load-balancing",
-				SecondaryLastState:         "load-balancing",
-				PrimaryLastScopes:          []string{"server1"},
-				SecondaryLastScopes:        []string{"server2"},
-				PrimaryLastFailoverAt:      exampleTime,
-				SecondaryLastFailoverAt:    exampleTime,
+				HAType:                      "dhcp4",
+				HAMode:                      "load-balancing",
+				PrimaryID:                   keaApp.ID,
+				PrimaryStatusCollectedAt:    exampleTime,
+				SecondaryStatusCollectedAt:  exampleTime,
+				PrimaryLastState:            "load-balancing",
+				SecondaryLastState:          "load-balancing",
+				PrimaryLastScopes:           []string{"server1"},
+				SecondaryLastScopes:         []string{"server2"},
+				PrimaryLastFailoverAt:       exampleTime,
+				SecondaryLastFailoverAt:     exampleTime,
+				PrimaryCommInterrupted:      &commInterrupted[0],
+				SecondaryCommInterrupted:    &commInterrupted[1],
+				PrimaryConnectingClients:    7,
+				SecondaryConnectingClients:  9,
+				PrimaryUnackedClients:       3,
+				SecondaryUnackedClients:     4,
+				PrimaryUnackedClientsLeft:   8,
+				SecondaryUnackedClientsLeft: 9,
+				PrimaryAnalyzedPackets:      10,
+				SecondaryAnalyzedPackets:    11,
 			},
 		},
 		{
@@ -853,17 +817,27 @@ func TestRestGetAppServicesStatus(t *testing.T) {
 				ServiceType: "ha_dhcp",
 			},
 			HAService: &dbmodel.BaseHAService{
-				HAType:                     "dhcp6",
-				HAMode:                     "hot-standby",
-				PrimaryID:                  keaApp.ID,
-				PrimaryStatusCollectedAt:   exampleTime,
-				SecondaryStatusCollectedAt: exampleTime,
-				PrimaryLastState:           "hot-standby",
-				SecondaryLastState:         "waiting",
-				PrimaryLastScopes:          []string{"server1"},
-				SecondaryLastScopes:        []string{},
-				PrimaryLastFailoverAt:      exampleTime,
-				SecondaryLastFailoverAt:    exampleTime,
+				HAType:                      "dhcp6",
+				HAMode:                      "hot-standby",
+				PrimaryID:                   keaApp.ID,
+				PrimaryStatusCollectedAt:    exampleTime,
+				SecondaryStatusCollectedAt:  exampleTime,
+				PrimaryLastState:            "hot-standby",
+				SecondaryLastState:          "waiting",
+				PrimaryLastScopes:           []string{"server1"},
+				SecondaryLastScopes:         []string{},
+				PrimaryLastFailoverAt:       exampleTime,
+				SecondaryLastFailoverAt:     exampleTime,
+				PrimaryCommInterrupted:      &commInterrupted[0],
+				SecondaryCommInterrupted:    nil,
+				PrimaryConnectingClients:    5,
+				SecondaryConnectingClients:  0,
+				PrimaryUnackedClients:       2,
+				SecondaryUnackedClients:     0,
+				PrimaryUnackedClientsLeft:   9,
+				SecondaryUnackedClientsLeft: 0,
+				PrimaryAnalyzedPackets:      123,
+				SecondaryAnalyzedPackets:    0,
 			},
 		},
 	}
@@ -909,6 +883,11 @@ func TestRestGetAppServicesStatus(t *testing.T) {
 	require.Equal(t, "127.0.0.1", haStatus.PrimaryServer.ControlAddress)
 	require.EqualValues(t, keaApp.ID, haStatus.PrimaryServer.AppID)
 	require.NotEmpty(t, haStatus.PrimaryServer.StatusTime.String())
+	require.EqualValues(t, 1, haStatus.PrimaryServer.CommInterrupted)
+	require.EqualValues(t, 7, haStatus.PrimaryServer.ConnectingClients)
+	require.EqualValues(t, 3, haStatus.PrimaryServer.UnackedClients)
+	require.EqualValues(t, 8, haStatus.PrimaryServer.UnackedClientsLeft)
+	require.EqualValues(t, 10, haStatus.PrimaryServer.AnalyzedPackets)
 
 	require.Equal(t, "secondary", haStatus.SecondaryServer.Role)
 	require.Len(t, haStatus.SecondaryServer.Scopes, 1)
@@ -918,6 +897,11 @@ func TestRestGetAppServicesStatus(t *testing.T) {
 	require.False(t, haStatus.SecondaryServer.InTouch)
 	require.Empty(t, haStatus.SecondaryServer.ControlAddress)
 	require.NotEmpty(t, haStatus.SecondaryServer.StatusTime.String())
+	require.EqualValues(t, 1, haStatus.SecondaryServer.CommInterrupted)
+	require.EqualValues(t, 9, haStatus.SecondaryServer.ConnectingClients)
+	require.EqualValues(t, 4, haStatus.SecondaryServer.UnackedClients)
+	require.EqualValues(t, 9, haStatus.SecondaryServer.UnackedClientsLeft)
+	require.EqualValues(t, 11, haStatus.SecondaryServer.AnalyzedPackets)
 
 	// Validate the status of the DHCPv6 pair.
 	status = statusList[1].Status.KeaStatus
@@ -934,6 +918,11 @@ func TestRestGetAppServicesStatus(t *testing.T) {
 	require.Equal(t, "hot-standby", haStatus.PrimaryServer.State)
 	require.GreaterOrEqual(t, haStatus.PrimaryServer.Age, int64(5))
 	require.Equal(t, "127.0.0.1", haStatus.PrimaryServer.ControlAddress)
+	require.EqualValues(t, 1, haStatus.PrimaryServer.CommInterrupted)
+	require.EqualValues(t, 5, haStatus.PrimaryServer.ConnectingClients)
+	require.EqualValues(t, 2, haStatus.PrimaryServer.UnackedClients)
+	require.EqualValues(t, 9, haStatus.PrimaryServer.UnackedClientsLeft)
+	require.EqualValues(t, 123, haStatus.PrimaryServer.AnalyzedPackets)
 
 	require.Equal(t, "standby", haStatus.SecondaryServer.Role)
 	require.Empty(t, haStatus.SecondaryServer.Scopes)
@@ -941,6 +930,116 @@ func TestRestGetAppServicesStatus(t *testing.T) {
 	require.GreaterOrEqual(t, haStatus.SecondaryServer.Age, int64(5))
 	require.False(t, haStatus.SecondaryServer.InTouch)
 	require.Empty(t, haStatus.SecondaryServer.ControlAddress)
+	require.EqualValues(t, -1, haStatus.SecondaryServer.CommInterrupted)
+	require.Zero(t, haStatus.SecondaryServer.ConnectingClients)
+	require.Zero(t, haStatus.SecondaryServer.UnackedClients)
+	require.Zero(t, haStatus.SecondaryServer.UnackedClientsLeft)
+	require.Zero(t, haStatus.SecondaryServer.AnalyzedPackets)
+}
+
+// Test that status of a HA service providing passive-backup mode is
+// parsed correctly.
+func TestRestGetAppServicesStatusPassiveBackup(t *testing.T) {
+	db, dbSettings, teardown := dbtest.SetupDatabaseTestCase(t)
+	defer teardown()
+
+	settings := RestAPISettings{}
+	// Configure the fake control agents to mimic returning a status of
+	// two HA services for Kea.
+	fa := storktest.NewFakeAgents(nil, nil)
+	fec := &storktest.FakeEventCenter{}
+	rapi, err := NewRestAPI(&settings, dbSettings, db, fa, fec)
+	require.NoError(t, err)
+	ctx := context.Background()
+
+	// Add a machine.
+	m := &dbmodel.Machine{
+		Address:   "localhost",
+		AgentPort: 8080,
+	}
+	err = dbmodel.AddMachine(db, m)
+	require.NoError(t, err)
+
+	// Add Kea application to the machine
+	var keaPoints []*dbmodel.AccessPoint
+	keaPoints = dbmodel.AppendAccessPoint(keaPoints, dbmodel.AccessPointControl, "127.0.0.1", "", 1234)
+	keaApp := &dbmodel.App{
+		ID:           0,
+		MachineID:    m.ID,
+		Type:         dbmodel.AppTypeKea,
+		Active:       true,
+		AccessPoints: keaPoints,
+		Daemons: []*dbmodel.Daemon{
+			dbmodel.NewKeaDaemon("dhcp4", true),
+		},
+	}
+	_, err = dbmodel.AddApp(db, keaApp)
+	require.NoError(t, err)
+	require.NotZero(t, keaApp.ID)
+
+	exampleTime := storkutil.UTCNow().Add(-5 * time.Second)
+	keaServices := []dbmodel.Service{
+		{
+			BaseService: dbmodel.BaseService{
+				ServiceType: "ha_dhcp",
+			},
+			HAService: &dbmodel.BaseHAService{
+				HAType:                   "dhcp4",
+				HAMode:                   "passive-backup",
+				PrimaryID:                keaApp.ID,
+				PrimaryStatusCollectedAt: exampleTime,
+				PrimaryLastState:         "passive-backup",
+				PrimaryLastScopes:        []string{"server1"},
+			},
+		},
+	}
+
+	// Add the services and associate them with the app.
+	for i := range keaServices {
+		err = dbmodel.AddService(db, &keaServices[i])
+		require.NoError(t, err)
+		err = dbmodel.AddDaemonToService(db, keaServices[i].ID, keaApp.Daemons[0])
+		require.NoError(t, err)
+	}
+
+	params := services.GetAppServicesStatusParams{
+		ID: keaApp.ID,
+	}
+	rsp := rapi.GetAppServicesStatus(ctx, params)
+
+	// Make sure that the response is ok.
+	require.IsType(t, &services.GetAppServicesStatusOK{}, rsp)
+	okRsp := rsp.(*services.GetAppServicesStatusOK)
+	require.NotNil(t, okRsp.Payload.Items)
+
+	// There should be one structure returned with a status of the
+	// DHCPv4 server.
+	require.Len(t, okRsp.Payload.Items, 1)
+
+	statusList := okRsp.Payload.Items
+
+	// Validate the status of the DHCPv4 pair.
+	status := statusList[0].Status.KeaStatus
+	require.NotNil(t, status.HaServers)
+
+	haStatus := status.HaServers
+	require.NotNil(t, haStatus.PrimaryServer)
+	require.Nil(t, haStatus.SecondaryServer)
+
+	require.EqualValues(t, keaApp.Daemons[0].ID, haStatus.PrimaryServer.ID)
+	require.Equal(t, "primary", haStatus.PrimaryServer.Role)
+	require.Len(t, haStatus.PrimaryServer.Scopes, 1)
+	require.Contains(t, haStatus.PrimaryServer.Scopes, "server1")
+	require.Equal(t, "passive-backup", haStatus.PrimaryServer.State)
+	require.GreaterOrEqual(t, haStatus.PrimaryServer.Age, int64(5))
+	require.Equal(t, "127.0.0.1", haStatus.PrimaryServer.ControlAddress)
+	require.EqualValues(t, keaApp.ID, haStatus.PrimaryServer.AppID)
+	require.NotEmpty(t, haStatus.PrimaryServer.StatusTime.String())
+	require.EqualValues(t, -1, haStatus.PrimaryServer.CommInterrupted)
+	require.Zero(t, haStatus.PrimaryServer.ConnectingClients)
+	require.Zero(t, haStatus.PrimaryServer.UnackedClients)
+	require.Zero(t, haStatus.PrimaryServer.UnackedClientsLeft)
+	require.Zero(t, haStatus.PrimaryServer.AnalyzedPackets)
 }
 
 func TestRestGetAppsStats(t *testing.T) {
@@ -949,7 +1048,8 @@ func TestRestGetAppsStats(t *testing.T) {
 
 	settings := RestAPISettings{}
 	fa := storktest.NewFakeAgents(nil, nil)
-	rapi, err := NewRestAPI(&settings, dbSettings, db, fa)
+	fec := &storktest.FakeEventCenter{}
+	rapi, err := NewRestAPI(&settings, dbSettings, db, fa, fec)
 	require.NoError(t, err)
 	ctx := context.Background()
 
@@ -980,7 +1080,7 @@ func TestRestGetAppsStats(t *testing.T) {
 		AccessPoints: keaPoints,
 		Daemons:      []*dbmodel.Daemon{},
 	}
-	err = dbmodel.AddApp(db, s1)
+	_, err = dbmodel.AddApp(db, s1)
 	require.NoError(t, err)
 
 	// add app bind9 to machine
@@ -994,7 +1094,7 @@ func TestRestGetAppsStats(t *testing.T) {
 		AccessPoints: bind9Points,
 		Daemons:      []*dbmodel.Daemon{},
 	}
-	err = dbmodel.AddApp(db, s2)
+	_, err = dbmodel.AddApp(db, s2)
 	require.NoError(t, err)
 
 	// get added app
@@ -1014,7 +1114,8 @@ func TestGetDhcpOverview(t *testing.T) {
 
 	settings := RestAPISettings{}
 	fa := storktest.NewFakeAgents(nil, nil)
-	rapi, err := NewRestAPI(&settings, dbSettings, db, fa)
+	fec := &storktest.FakeEventCenter{}
+	rapi, err := NewRestAPI(&settings, dbSettings, db, fa, fec)
 	require.NoError(t, err)
 	ctx := context.Background()
 
