@@ -19,6 +19,6 @@ export class AuthInterceptor implements HttpInterceptor {
     }
 
     intercept(req: HttpRequest<any>, next: HttpHandler): Observable<HttpEvent<any>> {
-        return next.handle(req).pipe(catchError(x => this.handleAuthError(x)))
+        return next.handle(req).pipe(catchError((x) => this.handleAuthError(x)))
     }
 }
